pitchtools.list_numbered_interval_numbers_pairwise
==================================================

.. autofunction:: abjad.tools.pitchtools.list_numbered_interval_numbers_pairwise.list_numbered_interval_numbers_pairwise
